@@ -20,7 +20,7 @@
 #' #returns metadata from all sites within 50 km of NEON site 'CPER'
 #'   getNearby(siteID="NEON:CPER", radius=50)
 #' #return metadata of sites within 10 km of Lat=41.7821 & Lon = -71.4204 (Cranston, RI, USA)
-#'   getNearby(lat=41.7821, lon = -71.4204, radius=10)}
+#'   getNearby(lat=41.7821, lon = -71.4204, radius=40)}
 
 #' @seealso
 #' \link[metScanR]{siteFinder}
@@ -61,8 +61,7 @@ getNearby<-function(siteID,lat,lon,radius,...){
         #id search:
         id.search<-gsub(".*:","",siteID)
         #match siteID with idType and id with site within the metadata file:
-        #browser()
-        idType.search.match<-grep(idType.search,lapply(lapply(c,"[[",
+        idType.search.match<-grep(idType.search,lapply(lapply(metadata,"[[",
                                                               "identifiers"), "[[", "idType"))
         id.search.match<-grep(id.search,lapply(lapply(metadata,"[[",
                                                       "identifiers"), "[[", "id"))
